"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAppInstance = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressMarketAimApiAppInstanceServiceUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/app-instance-manager-webapp',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/apps',
                destPath: '',
            },
        ],
        'wixapis.com': [
            {
                srcPath: '/apps',
                destPath: '',
            },
        ],
        'dev._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
            {
                srcPath: '/api/v1/instance',
                destPath: '/v1/instance',
            },
            {
                srcPath: '/api/v1/scripts',
                destPath: '/v1/scripts',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_app-management_app-instances';
/**
 * Retrieves data about the instance of your app that's installed on a Wix
 * site and data about the site itself. For example, to check whether the Wix user has installed a free or paid version of your app,
 * or to check which apps made by Wix are installed on the site.
 *
 * You must authenticate this method as a Wix app ([REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#wix-app) | [SDK](https://dev.wix.com/docs/build-apps/develop-your-app/access/about-identities#wix-apps)).
 *
 * To retrieve `site.ownerInfo` in the response, you must
 * have the __READ SITE OWNER EMAIL__ permission scope in addition to
 * __MANAGE YOUR APP__.
 */
function getAppInstance(payload) {
    function __getAppInstance({ host }) {
        const metadata = {
            entityFqdn: 'wix.devcenter.app_instance.v1.app_instance',
            method: 'GET',
            methodFqn: 'com.wixpress.market.aim.api.AppInstanceService.GetAppInstance',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMarketAimApiAppInstanceServiceUrl({
                protoPath: '/v1/instance',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'instance.billing.freeTrialInfo.endDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __getAppInstance;
}
exports.getAppInstance = getAppInstance;
//# sourceMappingURL=devcenter-app-instance-v1-app-instance-app-instances.http.js.map